data {
  int<lower=0> N; // number of observations
  int<lower=0> n_level_1; // number of level 1 groups
  int<lower=0> n_level_2; // number of level 2 groups
  int<lower=0> n_predictors; // number of predictors
  int<lower=0, upper=1> y[N]; // outcome (no eggs: 0, eggs: 1)
  int<lower=0, upper=n_level_1> level_1_assignments[N]; // level 1 group assignments
  int<lower=0, upper=n_level_2> level_2_assignments[N]; // level 2 group assignments
  row_vector[n_predictors] x[N]; // predictors

  real sea_days_std2[N];
  real sea_days_std2_sq[N];
  real sea_days_std2_cu[N];

}
parameters {
  vector[n_level_1] eta_a1;
  vector[n_level_2] eta_a2;
  vector[n_predictors] b;
  real<lower=0> sigma_a1;
  real<lower=0> sigma_a2;
  real mu_a1;
  real mu_a2;
  vector[n_level_1] eta_b_sea_days_std2;
  vector[n_level_1] eta_b_sea_days_std2_sq;
  vector[n_level_1] eta_b_sea_days_std2_cu;
  real<lower=0> sigma_b_sea_days_std2;
  real<lower=0> sigma_b_sea_days_std2_sq;
  real<lower=0> sigma_b_sea_days_std2_cu;
  real mu_b_sea_days_std2;
  real mu_b_sea_days_std2_sq;
  real mu_b_sea_days_std2_cu;

}
transformed parameters{
  vector[n_level_1] a1;
  vector[n_level_2] a2;
  vector[n_level_1] b_sea_days_std2;
  vector[n_level_1] b_sea_days_std2_sq;
  vector[n_level_1] b_sea_days_std2_cu;


a1 <- mu_a1 + sigma_a1 * eta_a1;
a2 <- mu_a2 + sigma_a2 * eta_a2;
b_sea_days_std2 <- mu_b_sea_days_std2 + sigma_b_sea_days_std2 * eta_b_sea_days_std2;
b_sea_days_std2_sq <- mu_b_sea_days_std2_sq + sigma_b_sea_days_std2_sq * eta_b_sea_days_std2_sq;
b_sea_days_std2_cu <- mu_b_sea_days_std2_cu + sigma_b_sea_days_std2_cu * eta_b_sea_days_std2_cu;


}
model {

  vector[N] y_hat;
  for (i in 1:N){
  y_hat[i] <- a1[level_1_assignments[i]] + a2[level_2_assignments[i]] + b_sea_days_std2[level_1_assignments[i]]*sea_days_std2[i] + b_sea_days_std2_sq[level_1_assignments[i]]*sea_days_std2_sq[i] + b_sea_days_std2_cu[level_1_assignments[i]]*sea_days_std2_cu[i] + x[i]*b;
}

  eta_a1 ~ normal(0,1);
  eta_a2 ~ normal(0, 1);
  eta_b_sea_days_std2 ~ normal(0, 1);
  eta_b_sea_days_std2_sq ~ normal(0, 1);
  eta_b_sea_days_std2_cu ~ normal(0, 1);
  mu_a1 ~ normal(0, 1);
  mu_a2 ~ normal(0, 1);
  mu_b_sea_days_std2 ~ normal(0, 1);
  mu_b_sea_days_std2_sq ~ normal(0, 1);
  mu_b_sea_days_std2_cu ~ normal(0, 1);
  sigma_a1 ~ cauchy(0, 5);
  sigma_a2~ cauchy(0, 5);
  sigma_b_sea_days_std2 ~ cauchy(0, 5);
  sigma_b_sea_days_std2_sq ~ cauchy(0, 5);
  sigma_b_sea_days_std2_cu ~ cauchy(0, 5);
  b ~ normal (0, 100);
  y ~ bernoulli_logit(y_hat);
}