data {
  int<lower=0> N; // number of observations
  int<lower=0> n_level_1; // number of level 1 groups
  int<lower=0> n_predictors; // number of predictors
  int<lower=0, upper=1> y[N]; // outcome 
  int<lower=0, upper=n_level_1> level_1_assignments[N]; // level 1 group assignments
  row_vector[n_predictors] x[N]; // predictors
}
parameters {
  vector[n_predictors] b;
  real<lower=0> sigma_a;
  real mu_a;
  vector[n_level_1] eta;
}
transformed parameters{
  vector[n_level_1] a;

  a <- mu_a + sigma_a * eta;

}
model {
  vector[N] y_hat;

  for (i in 1:N){
  y_hat[i] <- a[level_1_assignments[i]] + x[i]*b;
  }
  eta ~ normal(0, 1);
  mu_a ~ normal(0, 1);
  sigma_a ~ cauchy(0,5);
  b ~ normal (0, 100);
  y ~ bernoulli_logit(y_hat);
}
